==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/BindingResourcePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Binding resource properties payload
 * @property bindingParameters Binding parameters of the Binding resource
 * @property key The key of the bound resource
 * @property resourceId The Azure resource id of the bound resource
 */
public data class BindingResourcePropertiesArgs(
    public val bindingParameters: Output<Map<String, String>>? = null,
    public val key: Output<String>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs.builder()
            .bindingParameters(
                bindingParameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .key(key?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BindingResourcePropertiesArgs].
 */
@PulumiTagMarker
public class BindingResourcePropertiesArgsBuilder internal constructor() {
    private var bindingParameters: Output<Map<String, String>>? = null

    private var key: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Binding parameters of the Binding resource
     */
    @JvmName("ltehyipcpayuvobi")
    public suspend fun bindingParameters(`value`: Output<Map<String, String>>) {
        this.bindingParameters = value
    }

    /**
     * @param value The key of the bound resource
     */
    @JvmName("ckfyfpkjtodufbcr")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The Azure resource id of the bound resource
     */
    @JvmName("tbqlsvwopqlfvxdf")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Binding parameters of the Binding resource
     */
    @JvmName("wbskqllgisxguqmp")
    public suspend fun bindingParameters(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindingParameters = mapped
    }

    /**
     * @param values Binding parameters of the Binding resource
     */
    @JvmName("qbcnwdajyujlspsl")
    public fun bindingParameters(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bindingParameters = mapped
    }

    /**
     * @param value The key of the bound resource
     */
    @JvmName("ekfnbvwhxflwmehr")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The Azure resource id of the bound resource
     */
    @JvmName("lsvhwghgbvuvdtgi")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): BindingResourcePropertiesArgs = BindingResourcePropertiesArgs(
        bindingParameters = bindingParameters,
        key = key,
        resourceId = resourceId,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/appplatform/kotlin/inputs/BindingResourcePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.appplatform.kotlin.inputs

import com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * Binding resource properties payload
 * @property bindingParameters Binding parameters of the Binding resource
 * @property key The key of the bound resource
 * @property resourceId The Azure resource id of the bound resource
 */
public data class BindingResourcePropertiesArgs(
    public val bindingParameters: Output<Map<String, String>>? = null,
    public val key: Output<String>? = null,
    public val resourceId: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs =
        com.pulumi.azurenative.appplatform.inputs.BindingResourcePropertiesArgs.builder()
            .bindingParameters(
                bindingParameters?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.key.to(args0.value)
                    }).toMap()
                }),
            )
            .key(key?.applyValue({ args0 -> args0 }))
            .resourceId(resourceId?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BindingResourcePropertiesArgs].
 */
@PulumiTagMarker
public class BindingResourcePropertiesArgsBuilder internal constructor() {
    private var bindingParameters: Output<Map<String, String>>? = null

    private var key: Output<String>? = null

    private var resourceId: Output<String>? = null

    /**
     * @param value Binding parameters of the Binding resource
     */
    @JvmName("egkdkbblvbfhkvgv")
    public suspend fun bindingParameters(`value`: Output<Map<String, String>>) {
        this.bindingParameters = value
    }

    /**
     * @param value The key of the bound resource
     */
    @JvmName("emmjvjmkktrwlkuy")
    public suspend fun key(`value`: Output<String>) {
        this.key = value
    }

    /**
     * @param value The Azure resource id of the bound resource
     */
    @JvmName("hudkglyjdjlceknl")
    public suspend fun resourceId(`value`: Output<String>) {
        this.resourceId = value
    }

    /**
     * @param value Binding parameters of the Binding resource
     */
    @JvmName("flarhvduhjeyfwuw")
    public suspend fun bindingParameters(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.bindingParameters = mapped
    }

    /**
     * @param values Binding parameters of the Binding resource
     */
    @JvmName("twtuxedvjwwhlyyo")
    public fun bindingParameters(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.bindingParameters = mapped
    }

    /**
     * @param value The key of the bound resource
     */
    @JvmName("fpllggbwiedqqjxn")
    public suspend fun key(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.key = mapped
    }

    /**
     * @param value The Azure resource id of the bound resource
     */
    @JvmName("bguukvqponvgxaqm")
    public suspend fun resourceId(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceId = mapped
    }

    internal fun build(): BindingResourcePropertiesArgs = BindingResourcePropertiesArgs(
        bindingParameters = bindingParameters,
        key = key,
        resourceId = resourceId,
    )
}
